# pandas-msgpack

**pandas-msgpack** is a package providing an interface to msgpack from pandas

This package is a fork of the original `pandas-msgpack`, which has not been maintained since
its inception in 2017 by the PyData team. However, it is to date an extremely performant dataformat.

This fork simply maintains the `pandas-msgpack` format to be up to speed with current developmental
changes in both `pandas` and `msgpack`. As we are not the original authors of this package, we do not
claim any ownership of the original code. We are simply maintaining it so we can use it in our main project ISF (https://github.com/mpinb/in_silico_framework).
We have no interest in adding new features, or making this broadly applicable.



## Installation

Install latest release version via pip

```shell
pip install isf-pandas-msgpack
```